==> rflowcyt_1.4.0.tar.gz: rflowcyt/man/plotdensity.FCS.Rd <==
\name{plotdensity.FCS}
\alias{plotdensity.FCS}
\alias{densityplot.FCS}

\title{Create density plots one parameter of one (or more) FCS object(s)}
\description{
  Produce density plot(s) using the \code{\link{density.lf}} function of
  the  \code{\link{locfit}} library. a single column variable specified from the
  data of one (or more) FCS object(s).
}

\usage{
plotdensity.FCS(data,varpos,xlab,ylab,col, xlim = NULL, ylim = NULL,main=NULL,...)        
}

\arguments{
  \item{data}{a list of one (or more) FCS object(s) or a cytoSet object}

  \item{varpos}{the numerical column variable position of the data of
    the FCS object}
  
  \item{xlab}{a title for the x axis}

  \item{ylab}{a title for the y axis}
  
  \item{col}{The colors for lines and points. Multiple colors can be
    specified so that each point can be given its own color. If there
    are fewer colors than points they are recycled in the standard
    fashion. Lines will all be plotted in the first colour specified.}
  
   \item{xlim}{limits for the x axis}

   \item{ylim}{limits for the y axis}
   
   \item{main}{title of the plot}
   
  \item{...}{any other arguments are passed to the \code{\link{plot}}
  function}
}  

\details{
  Produce density plot(s) using the \code{\link{density.lf}} function of
  the  \code{\link{locfit}} library. 
  Other options from the functions \code{\link{plot}}.
}

\value{
  None.
}

\author{N. Le Meur}


\seealso{\code{\link{density.lf}}}

\examples{

 if (require(rfcdmin)) {
  ##Obtain the location of the fcs files 
  pathFiles<-system.file("bccrc", package="rfcdmin")
  drugFiles<-dir(pathFiles)

  ## Read a serie of FCS files
  drugData<-read.series.FCS(drugFiles,path=pathFiles,MY.DEBUG=FALSE)

  }

 ##Draw a density plot for the Foward SCatter parameter for the
 ##differents aliquots (of the same cell line) tested with different
 ##compounds.
 plotdensity.FCS(drugData,varpos=c(1),main="FSC for the aliquots treated with different compounds",ylim=c(0,0.005),ylab="Density of cells")
}
\keyword{hplot}

==> rflowcyt_1.6.0.tar.gz: rflowcyt/man/plotdensity.FCS.Rd <==
\name{plotdensity.FCS}
\alias{plotdensity.FCS}
\alias{densityplot.FCS}

\title{Create density plots one parameter of one (or more) FCS object(s)}
\description{
  Produce density plot(s) using the \code{\link[locfit]{density.lf}} function of
  the  \code{\link[locfit]{locfit}} library. a single column variable specified from the
  data of one (or more) FCS object(s).
}

\usage{
plotdensity.FCS(data,varpos,xlab,ylab,col, xlim = NULL, ylim = NULL,main=NULL,...)        
}

\arguments{
  \item{data}{a list of one (or more) FCS object(s) or a cytoSet object}

  \item{varpos}{the numerical column variable position of the data of
    the FCS object}
  
  \item{xlab}{a title for the x axis}

  \item{ylab}{a title for the y axis}
  
  \item{col}{The colors for lines and points. Multiple colors can be
    specified so that each point can be given its own color. If there
    are fewer colors than points they are recycled in the standard
    fashion. Lines will all be plotted in the first colour specified.}
  
   \item{xlim}{limits for the x axis}

   \item{ylim}{limits for the y axis}
   
   \item{main}{title of the plot}
   
  \item{...}{any other arguments are passed to the \code{\link{plot}}
  function}
}  

\details{
  Produce density plot(s) using the \code{\link[locfit]{density.lf}} function of
  the  \code{\link[locfit]{locfit}} library. 
  Other options from the functions \code{\link{plot}}.
}

\value{
  None.
}

\author{N. Le Meur}


\seealso{\code{\link[locfit]{density.lf}}}

\examples{

 if (require(rfcdmin)) {
  ##Obtain the location of the fcs files 
  pathFiles<-system.file("bccrc", package="rfcdmin")
  drugFiles<-dir(pathFiles)

  ## Read a serie of FCS files
  drugData<-read.series.FCS(drugFiles,path=pathFiles,MY.DEBUG=FALSE)

  }

 ##Draw a density plot for the Foward SCatter parameter for the
 ##differents aliquots (of the same cell line) tested with different
 ##compounds.
 plotdensity.FCS(drugData,varpos=c(1),main="FSC for the aliquots treated with different compounds",ylim=c(0,0.005),ylab="Density of cells")
}
\keyword{hplot}
